You are viewing a plain text version of this content. The canonical link for it is here.
Posted to hdfs-issues@hadoop.apache.org by "Konstantin Boudnik (JIRA)" <ji...@apache.org> on 2009/12/01 00:24:20 UTC

[jira] Commented: (HDFS-797) TestHDFSCLI much slower after HDFS-265 merge

    [ https://issues.apache.org/jira/browse/HDFS-797?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=12783936#action_12783936 ] 

Konstantin Boudnik commented on HDFS-797:
-----------------------------------------

Running the same test locally (BSD, Linux) and looking into latest successful [Hudson build for the trunk|http://hudson.zones.apache.org/hudson/view/Hadoop/job/Hadoop-Hdfs-trunk/150/testReport/] shows that TestHDFSCLI normally completes in between 1 min 40 seconds to 2 min sharp.

The reported behavior hasn't been observed before.

> TestHDFSCLI much slower after HDFS-265 merge
> --------------------------------------------
>
>                 Key: HDFS-797
>                 URL: https://issues.apache.org/jira/browse/HDFS-797
>             Project: Hadoop HDFS
>          Issue Type: Bug
>          Components: hdfs client
>    Affects Versions: 0.21.0, 0.22.0
>            Reporter: Todd Lipcon
>
> After the merge of HDFS-265 into trunk, TestHDFSCLI takes much longer to run (>10min, got tired of waiting). Changing dataQueue.wait(1000) to dataQueue.wait(10) on line 2708 speeds up the test back to its original performance. This isn't a fix, but displays the issue - somehow the thread isn't getting properly interrupted. In general this probably represents a performance regression for the exit of all HDFS writers (most noticeable in CLI tools)

-- 
This message is automatically generated by JIRA.
-
You can reply to this email to add a comment to the issue online.